@@ -91,8 +91,8 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 	ClutterActor *marker;
 	ClutterActor *layer_actor;
 	ChamplainLabel *self;
-	ClutterColor city_color = { 0x10, 0x10, 0xff, 0xbb };
-	ClutterColor voicegram_color = { 0x00, 0xff, 0x10, 0xbb };	
+	ClutterColor city_color = { 0xa5, 0x6d, 0xe2, 0xbb };
+	ClutterColor voicegram_color = { 0x6d, 0xa5, 0xe2, 0xbb };
 	ClutterColor text_color = { 0xff, 0xff, 0xff, 0xff };
 	LocationCallbackData callback_data;
 	gchar *station = NULL, *station_link;
@@ -128,6 +128,7 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 	  champlain_marker_animate_in(CHAMPLAIN_MARKER (marker));
 	  voinfo = voinfo->next;
 	}
+	champlain_marker_layer_set_all_markers_draggable (layer);
 	clutter_actor_show (layer_actor);
 	return layer;
 }
@@ -137,8 +138,6 @@ on_location_timeout (gpointer user_data)
 {
         g_clear_object (&client);
         g_clear_object (&simple);
-        g_main_loop_quit (main_loop);
-
         return FALSE;
 }
 
@@ -485,18 +484,14 @@ gps_callback (GClueSimple *simple, GpsCallbackData *data)
 	const char *name, *name_city, *name_country;
 	/* GeocodeForward *fwd; */
 	/* GList *list; */
-
         gdouble altitude, speed, heading;
         GVariant *timestamp;
         GTimeVal tv = { 0 };
         const char *desc;
-
-	lat_gps = gclue_location_get_latitude (location);
-	lon_gps = gclue_location_get_longitude (location);
-
-	champlain_view_center_on (CHAMPLAIN_VIEW (data->view), lat_gps, lon_gps);
-	champlain_location_set_location (CHAMPLAIN_LOCATION (data->voice_marker), lat_gps, lon_gps);
-
+	/* lat_gps = gclue_location_get_latitude (location); */
+	/* lon_gps = gclue_location_get_longitude (location); */
+	/* champlain_view_center_on (CHAMPLAIN_VIEW (data->view), lat_gps, lon_gps); */
+	/* champlain_location_set_location (CHAMPLAIN_LOCATION (data->voice_marker), lat_gps, lon_gps); */
 	return TRUE;
 }
 
@@ -590,7 +585,7 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 {
 	FILE *voice_pointer = NULL;
 	GDateTime *datestamp = g_date_time_new_now_utc ();
-	gchar *filename_voice = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", g_get_real_name(), ".voice", NULL);
+	gchar *filename_voice = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/GNOME.voice", NULL);
 	gchar *string;
 	const char *charset;
 	guint status;
@@ -601,24 +596,41 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 	GBytes *bytes;
 	gchar *voicegram_save_url;
 	voiceinfo = (VoiceInfo *) data;
+	/* Geographical Position System Location. */
+	/* lat_gps = gclue_location_get_latitude (location); */
+	/* lon_gps = gclue_location_get_longitude (location); */
+	/* Version and current date. */
+	t_timebuffer = g_date_time_new_now_utc ();
+	g_date_clear (&d, 1);
+	g_date_set_time_t (&d, time (NULL));
+	g_date_strftime (timebuffer, sizeof (timebuffer), "%s", &d);
 	session = soup_session_sync_new ();
 	voice_pointer = fopen(filename_voice, "w");
 	fprintf(voice_pointer, "<voice version='%s'>\n", VERSION);
 	fprintf(voice_pointer, "  <station name='%s' uri='http://%s/GNOME.ogg'>\n",
 		g_get_real_name(),
 		g_get_host_name());
-	fprintf(voice_pointer, "    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lon_gps, g_get_host_name());
+	fprintf(voice_pointer, "    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name());
 	fprintf(voice_pointer, "    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice");
 	fprintf(voice_pointer, "  </station>\n");
 	fprintf(voice_pointer, "</voice>\n");
 	fclose(voice_pointer);
-	voicegram_save_url = g_strconcat("https://www.gnomevoice.org/stream/?notBefore=", g_date_time_format_iso8601 (t_timebuffer), g_strconcat("&notAfter=", g_date_time_format_iso8601 (t_timebuffer), "&label=GNOME&sofset=0&eofset=", strlen(voice_pointer), "&MAX_FILE_SIZE=5000000&userfile=", NULL), filename_voice, NULL);
-	g_print ("Voicegram GET %s\n", voicegram_save_url);
-	msg = soup_message_new ("GET", voicegram_save_url);
+	voicegram_save_url = g_strconcat(g_strconcat("https://www.gnomevoice.org/stream/?notBefore=", g_date_time_format_iso8601 (t_timebuffer), NULL), g_strconcat("&notAfter=",g_date_time_format_iso8601 (t_timebuffer), "&label=GNOME&sofset=0&eofset=", NULL), g_strconcat(strlen(voice_pointer), "&MAX_FILE_SIZE=5000000&userfile=", filename_voice, NULL));
+	msg = soup_message_new ("POST", voicegram_save_url);
 	soup_message_set_request (msg, "application/xml",
 				  SOUP_MEMORY_COPY,
-				  voice_pointer,
-				  strlen (voice_pointer));
+				  g_strconcat(g_strconcat("<voice version='", VERSION, "'>\n", NULL),
+					      g_strconcat("  <station name='", g_get_real_name(), "' uri='http://", g_get_host_name(), "/GNOME.ogg'>\n", NULL),
+					      g_strconcat("    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name(), NULL),
+					      g_strconcat("    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice", NULL),
+					      g_strconcat("  </station>\n", NULL),
+					      g_strconcat("</voice>\n", NULL),NULL),
+				  strlen(g_strconcat(g_strconcat("<voice version='", VERSION, "'>\n", NULL),
+						     g_strconcat("  <station name='", g_get_real_name(), "' uri='http://", g_get_host_name(), "/GNOME.ogg'>\n", NULL),
+						     g_strconcat("    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name(), NULL),
+						     g_strconcat("    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice", NULL),
+						     g_strconcat("  </station>\n", NULL),
+						     g_strconcat("</voice>\n", NULL),NULL)));
 	status = soup_session_send_message (session, msg);
 	g_object_unref (msg);
 	g_object_unref (session);
@@ -628,7 +640,8 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
         } else {
                 GMainLoop *loop = main_loops;
                 g_main_loop_quit(loop);
-                gtk_main_quit();
+		g_object_unref (loop);
+		gtk_main_quit();
         }
 	/* gst_element_send_event(data, gst_event_new_eos()); */
 }
@@ -683,7 +696,7 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 1.1.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 1.1.1", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Voicegram", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
@@ -700,20 +713,14 @@ main (gint argc, gchar **argv)
 	char *contents;
 	gsize length;
 	
-	/* Version and current date. */
-	g_date_clear (&d, 1);
-	g_date_set_time_t (&d, time (NULL));
-	g_date_strftime (timebuffer, sizeof (timebuffer), "%s", &d);
-	t_timebuffer = g_date_time_new_now_utc ();
-	voice_filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
-				     g_get_real_name(), ".voice", NULL);
+	voice_filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/GNOME.voice", NULL);
 	voinfo = gnome_voice_file_loader (voinfo, voice_filename);
 	// gtk_init(&argc, &argv);
 	if (argc < 2) {
 	  fprintf(stderr, "No Voice Stream typed on the command line\n");
 	}
 
-	context = g_option_context_new ("- Voice 1.1.0");
+	context = g_option_context_new ("- Voice 1.1.1");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
@@ -726,15 +733,15 @@ main (gint argc, gchar **argv)
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.1.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.1.1");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 1.1.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 1.1.1!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Voicegram:"));
 	title_entry = gtk_entry_new();
 	gtk_entry_set_max_length (title_entry, 256);
-	if (g_strcmp0(title_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(title_entry), g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", g_get_real_name(), ".voice", NULL)); else gtk_entry_set_text(GTK_ENTRY(title_entry), gtk_entry_get_text(GTK_ENTRY(title_entry)));
+	if (g_strcmp0(title_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(title_entry), g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/GNOME.voice", NULL)); else gtk_entry_set_text(GTK_ENTRY(title_entry), gtk_entry_get_text(GTK_ENTRY(title_entry)));
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(title_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(title_entry),
@@ -807,7 +814,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 1.1.0",
+				 GST_TAG_COMMENT, "Voice 1.1.1",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
@@ -853,7 +860,7 @@ main (gint argc, gchar **argv)
 	/* oscilloscope_visual = create_oscilloscope_visual (); */
         /* gnome_voice_add_visual_oscilloscope (layer, GNOME_VOICE_MARKER (oscilloscope_visual)); */
 
-
+#if 0
 	gclue_simple_new ("gnome-voice",
 			  accuracy_level,
 			  time_threshold,
@@ -861,7 +868,7 @@ main (gint argc, gchar **argv)
 			  CHAMPLAIN_VIEW (view));
 
 	location = gclue_simple_get_location (GCLUE_SIMPLE(simple));
-
+#endif
 	/* Finish initialising the map view */
 	g_object_set (G_OBJECT (actor), "zoom-level", 1,
 		      "kinetic-mode", TRUE, NULL);
